# Autogenerated by Astropy-affiliated package ligo.skymap's setup.py on 2019-11-16 21:21:44 UTC
import datetime

version = "0.1.14"
githash = "6700e6a991e99afbbebe3632d2f3bfe8aedd06a4"


major = 0
minor = 1
bugfix = 14

version_info = (major, minor, bugfix)

release = True
timestamp = datetime.datetime(2019, 11, 16, 21, 21, 44)
debug = False

astropy_helpers_version = "3.2.2"
